Crate credibil_vc

Crate credibil_vc 

An API for the issuance and verification of Verifiable Credentials based on the OpenID for Verifiable Credential Issuance and OpenID for Verifiable Presentations specifications.

Feature Flags

There is no default feature. The following features are available:

  • issuer - Enables the issuer API.
  • verifier - Enables the verifier API.

Modules

did
Re-export DID resolution
infosec
Re-export cryptographic types and functions
provider
Re-export top-level provider traits and types
test_utils
Test Utilities for Credibil VC
urlencode
Re-export basic types

Macros

snapshot
Configure Insta snapshot name.

Enums

Kind
Re-export basic types Kind allows serde to serialize/deserialize a string or an object.
Quota
Re-export basic types Quota allows serde to serialize/deserialize a single object or a set of objects.