pub enum ContentAlgorithm {
A256Gcm,
XChaCha20Poly1305,
}Expand description
The algorithm used to perform authenticated content encryption. That is, encrypting the plaintext to produce the ciphertext and the Authentication Tag. MUST be an AEAD algorithm.
Variants
A256Gcm
AES GCM using a 256-bit key.
XChaCha20Poly1305
XChaCha20-Poly1305 is a competitive alternative to AES-256-GCM because it’s fast and constant-time without hardware acceleration (resistent to cache-timing attacks). It also has longer nonce length to alleviate the risk of birthday attacks when nonces are generated randomly.